@@ -140,10 +140,10 @@ class googleRoutesearchDownloader(Thread):
             if str.find("Continue straight") == 0:
                 ico_name = "./plugins/ico_turn_32_32.png"
                 ico = gdk.pixbuf_new_from_file(ico_name)
-            elif str.find("Turn left") == 0:
+            elif str.find("Turn left") == 0 or str.find("Take the 1st left") == 0 or str.find("Take the 2nd left") == 0:
                 ico_name = "./plugins/ico_turn_left_32_32.png"
                 ico = gdk.pixbuf_new_from_file(ico_name)
-            elif str.find("Turn right") == 0:
+            elif str.find("Turn right") == 0 or str.find("Take the 1st right") == 0 or str.find("Take the 2nd right") == 0 :
                 ico_name = "./plugins/ico_turn_right_32_32.png"
                 ico = gdk.pixbuf_new_from_file(ico_name)
             elif str.find("Slight right") == 0:
@@ -152,6 +152,15 @@ class googleRoutesearchDownloader(Thread):
             elif str.find("Slight left") == 0:
                 ico_name = "./plugins/ico_turn_sleft_32_32.png"
                 ico = gdk.pixbuf_new_from_file( ico_name)
+            elif str.find("Keep left") == 0:
+                ico_name = "./plugins/ico_turn_keep_left_32_32.png"
+                ico = gdk.pixbuf_new_from_file( ico_name)
+            elif str.find("Keep right") == 0:
+                ico_name = "./plugins/ico_turn_keep_right_32_32.png"
+                ico = gdk.pixbuf_new_from_file( ico_name)
+            elif str.find("Make a U-turn") == 0:
+                ico_name = "./plugins/ico_turn_u_32_32.png"
+                ico = gdk.pixbuf_new_from_file( ico_name)
             self.geonames.markers.append([
                                  float(sll[0]),float(sll[1]),
                                  str,
@@ -444,7 +453,7 @@ class google_routesearch:
                         t = int( time.strftime("%Y%m%d%H%M%S", time.localtime() ) )
 
 
-                        info = "%s\n%s" % ( self.osmMapa.distance_to_string(dis_to_key), m[2] )
+                        info = "in: %s\n%s" % ( self.osmMapa.distance_to_string(dis_to_key), m[2] )
                         self.osmMapa.draw_cloud( cr, 50,5, info, 20, False)
                         if m[4]<> None:
                             ico = cairo.ImageSurface.create_from_png( m[4] )
