@@ -31,6 +31,10 @@ osmgpsmap
     http://nzjrs.github.com/osm-gps-map/docs/reference/html/api-index-full.html
 
 
+
+paypal
+http://yoyo.ghost.pl/yosmapa/
+
 """
 import math
 import time
@@ -59,6 +63,9 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.18"
 """
+0.18-4
+    add donate and about
+    speed up what I can less redraw
 0.18-3
     speed up what I can
 0.18-2
@@ -288,6 +295,32 @@ class MyDialog( hildon.Dialog ):
     def on_bt_full(self, w, dialog):
         dialog.destroy()
         self.osmMapa.fullscreen_toggle()
+    def on_bt_donate(self,w):
+        os.system("dbus-send --system --type=method_call --dest=\"com.nokia.osso_browser\" --print-reply /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:\"yoyo.ghost.pl/yosmapa/\"")
+    def on_bt_about(self,w):
+        d = hildon.Dialog()
+        d.set_title("About")
+        d.set_size_request(640, 480)
+
+        mvbox = gtk.VBox()
+        panel = hildon.PannableArea()
+        panel.add_with_viewport(mvbox)
+
+        label = gtk.Label("""Plugin oriented navigation application based on Open Street Map.
+
+App version: """+version+"""
+Autor: Bartlomiej Ceglik <yoyoek[noSpam]wp.pl>""")
+        mvbox.pack_start(label,True)
+
+        hbox = gtk.HBox()
+        img = gtk.Image()
+        img.set_from_file("./imgs/ico_arrow_d_64_64.png")
+        hbox.pack_start(img,False)
+        hbox.pack_start(panel,True)
+        d.vbox.pack_start(hbox, True)
+        d.show_all()
+        d.run()
+        d.destroy()
 
     def __init__(self, osmMapa):
 
@@ -388,6 +421,19 @@ class MyDialog( hildon.Dialog ):
 
         mvbox.pack_start( hbox, False )
 
+
+        hbox = gtk.HBox()
+        bt_donate = gtk.Button("Donate")
+        bt_donate.connect("clicked", self.on_bt_donate)
+        hbox.pack_start(bt_donate, False)
+
+        bt_about = gtk.Button("About")
+        bt_about.connect("clicked",self.on_bt_about)
+        hbox.pack_start(bt_about, False)
+
+        mvbox.pack_start(hbox,False)
+
+
         # plugins menagment
         pb_plugs = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH,
                                         hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
@@ -487,66 +533,71 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         self.pb_gps_on = cairo.ImageSurface.create_from_png( './imgs/i_gps_on.png' )
         self.pb_gps = cairo.ImageSurface.create_from_png( './imgs/i_gps.png' )
         self.pb_menu = cairo.ImageSurface.create_from_png( './imgs/ico_work_64_64.png' )
-        
+        self.make_drawing = 1
 
     def do_draw(self, gpsmap, gdkdrawable):
         #return None
-        if timing_osd:
-            t = time.time()
-        
-        self.size = gdkdrawable.get_size()
-        x = self.size[0]-64
+        if self.make_drawing:
+            if timing_osd:
+                t = time.time()
 
-        cr = gdkdrawable.cairo_create()
+            self.size = gdkdrawable.get_size()
+            x = self.size[0]-64
 
-        cr.set_source_surface( self.pb_plus, x,10 )
-        cr.paint()
+            cr = gdkdrawable.cairo_create()
 
-        if gpsPresent:
-            if CONFIG['gpslock'] == 1:
-                cr.set_source_surface( self.pb_gps_on, x,100 )
-            else:
-                cr.set_source_surface( self.pb_gps, x,100 )
+            cr.set_source_surface( self.pb_plus, x,10 )
             cr.paint()
 
-            try:
-                self.osmMapa.osm.props.gps_track_highlight_radius = (gps.accuracy/gps.acc_scale[self.osmMapa.osm.props.zoom])*10
-            except:
-                self.osmMapa.osm.props.gps_track_highlight_radius = 0
-                print "GPS manager: accurasy is insain (",self.accuracy,")"
+            if gpsPresent:
+                if CONFIG['gpslock'] == 1:
+                    cr.set_source_surface( self.pb_gps_on, x,100 )
+                else:
+                    cr.set_source_surface( self.pb_gps, x,100 )
+                cr.paint()
+
+                try:
+                    self.osmMapa.osm.props.gps_track_highlight_radius = (gps.accuracy/gps.acc_scale[self.osmMapa.osm.props.zoom])*10
+                except:
+                    self.osmMapa.osm.props.gps_track_highlight_radius = 0
+                    print "GPS manager: accurasy is insain (",self.accuracy,")"
 
 
-        cr.set_source_surface( self.pb_min, x,200 )
-        cr.paint()
-        cr.set_source_surface( self.pb_menu, x,self.size[1]-100 )
-        cr.paint()
+            cr.set_source_surface( self.pb_min, x,200 )
+            cr.paint()
+            cr.set_source_surface( self.pb_menu, x,self.size[1]-100 )
+            cr.paint()
 
-        plug_nr = 0
-        for plugin in self.osmMapa.plugins_list:
-            plugin_name = plugin[1]
-            if CONFIG[plugin_name] and plugin[2]:
-                if len(plugin) == 3:
-                    plugin.append( plugin[0].get_menu_widgets(self) )
-                if plugin[3] <> None:
-                    cr.set_source_surface( plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset )
-                    cr.paint()
-                    plug_nr+=1
+            plug_nr = 0
+            for plugin in self.osmMapa.plugins_list:
+                plugin_name = plugin[1]
+                if CONFIG[plugin_name] and plugin[2]:
+                    if len(plugin) == 3:
+                        plugin.append( plugin[0].get_menu_widgets(self) )
+                    if plugin[3] <> None:
+                        cr.set_source_surface( plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset )
+                        cr.paint()
+                        plug_nr+=1
 
 
 
 
-        if self.osmMapa.osm.props.tiles_queued != 0:
-            str = "Downloading images (%i)" % self.osmMapa.osm.props.tiles_queued
-            cr.set_source_rgb(0.0, 0.0, 0.0)
-            cr.select_font_face("Georgia")
-            cr.set_font_size(15)
-            cr.move_to(10,15)
-            cr.show_text(str)
-        if timing_osd:
-            print "YosmapaOSD do_draw in:",(time.time()-t)
+            if self.osmMapa.osm.props.tiles_queued != 0:
+                str = "Downloading images (%i)" % self.osmMapa.osm.props.tiles_queued
+                cr.set_source_rgb(0.0, 0.0, 0.0)
+                cr.select_font_face("Georgia")
+                cr.set_font_size(15)
+                cr.move_to(10,15)
+                cr.show_text(str)
+            if timing_osd:
+                print "YosmapaOSD do_draw in:",(time.time()-t)
+
+            self.make_drawing = 0
+
         return None
 
     def do_render(self, gpsmap):
+        self.make_drawing = 1
         pass
 
     def do_busy(self):
@@ -930,7 +981,7 @@ class UI(gtk.Window):
         y+=10
         height+=4
         width+=4
-        
+
         cr.arc (x + width - radius, y + radius, radius, -90 * degrees, 0 * degrees)
         cr.arc (x + width - radius, y + height - radius, radius, 0 * degrees, 90 * degrees)
         cr.arc (x + radius, y + height - radius, radius, 90 * degrees, 180 * degrees)
@@ -956,7 +1007,7 @@ class UI(gtk.Window):
 
 
         self.clikable_clouds.append( [ x,y,x+width,y+height, float(math.degrees(rlat)), float(math.degrees(rlon)) ] )
-        
+
         return True
 
     def point_test(self, lat, lon, x,y):
@@ -1182,35 +1233,37 @@ class PluginsLayer(gobject.GObject, osmgpsmap.GpsMapLayer):
         gobject.GObject.__init__(self)
         self.osmMapa = osmMapa
         self.plugins = plugins
+        self.make_draw = 1
 
     def do_draw(self, gpsmap, gdkdrawable):
-        
-        if timing_plugins:
-            t = time.time()
-            
-        if CONFIG['work_work_work']:
-            self.osmMapa.clikable_clouds = []
-            for plugin in self.plugins:
-                if CONFIG[plugin[1]]:
-                    try:
-                        if timing_plugins:                            
-                            tp = time.time()
-                        plugin[0].do_draw(gpsmap, gdkdrawable)
-                        if timing_plugins:
-                            print "plugin ", plugin[1]," in ",(time.time()-tp)
-                    except Exception, e:
-                        print "PluginsLayer do_draw ERROR (",plugin[1],"):", e
-        if timing_plugins:
-            print "PluginsLayers in",(time.time()-t)
+        if self.make_draw:
+            if timing_plugins:
+                t = time.time()
+
+            if CONFIG['work_work_work']:
+                self.osmMapa.clikable_clouds = []
+                for plugin in self.plugins:
+                    if CONFIG[plugin[1]]:
+                        try:
+                            if timing_plugins:
+                                tp = time.time()
+                            plugin[0].do_draw(gpsmap, gdkdrawable)
+                            if timing_plugins:
+                                print "plugin ", plugin[1]," in ",(time.time()-tp)
+                        except Exception, e:
+                            print "PluginsLayer do_draw ERROR (",plugin[1],"):", e
+            if timing_plugins:
+                print "PluginsLayers in",(time.time()-t)
+            self.make_draw = 0
 
     def do_render(self, gpsmap):
+        self.make_draw = 1
         pass
 
     def do_busy(self):
         return False
 
     def do_button_press(self, gpsmap, gdkeventbutton):
-
         return False
 gobject.type_register(PluginsLayer)
 
